@@ -2,17 +2,13 @@
 # flake8: noqa
 """Top-level module for flox ."""
 
-from . import cache
+from . import cache, cohorts, factorize
 from .aggregations import Aggregation, Scan, is_supported_aggregation
-from .core import (
-    groupby_reduce,
-    groupby_scan,
-    rechunk_for_blockwise,
-    rechunk_for_cohorts,
-    ReindexStrategy,
-    ReindexArrayType,
-)
+from .core import groupby_reduce
 from .options import set_options
+from .rechunk import rechunk_for_blockwise, rechunk_for_cohorts
+from .reindex import ReindexArrayType, ReindexStrategy
+from .scan import groupby_scan
 
 
 def _get_version():
